============
summarysplit
============

This :code:`summarysplit` executable is designed to split the posterior samples
contained within a file into N seperate files. If the input file has more than
one analysis (e.g. a PESummary metafile), the posterior samples for each
analysis is split into N separate files.

To see help for this executable please run:

.. code-block:: console

    $ summarysplit --help

.. program-output:: summarysplit --help
